#!/bin/sh
### $Id: run.sh,v 1.1 2005/11/09 02:59:06 lzq Exp $ ###

DIRNAME=`dirname $0`
PROGNAME=`basename $0`
GREP="grep"

# Use the maximum available, or set MAX_FD != -1 to use that
MAX_FD="maximum"

#
# Helper to complain.
#
warn() {
    echo "${PROGNAME}: $*"
}

#
# Helper to puke.
#
die() {
    warn $*
    exit 1
}

# OS specific support (must be 'true' or 'false').
cygwin=false;
darwin=false;
case "`uname`" in
    CYGWIN*)
        cygwin=true
        ;;

    Darwin*)
        darwin=true
        ;;
esac

# Read an optional running configuration file
if [ "x$RUN_CONF" = "x" ]; then
    RUN_CONF="$DIRNAME/run.conf"
fi
if [ -r "$RUN_CONF" ]; then
    . "$RUN_CONF"
fi

# For Cygwin, ensure paths are in UNIX format before anything is touched
if $cygwin ; then
    [ -n "$SOPCAST_HOME" ] &&
        SOPCAST_HOME=`cygpath --unix "$SOPCAST_HOME"`
    [ -n "$JAVA_HOME" ] &&
        JAVA_HOME=`cygpath --unix "$JAVA_HOME"`
    [ -n "$JAVAC_JAR" ] &&
        JAVAC_JAR=`cygpath --unix "$JAVAC_JAR"`
fi

# Setup SOPCAST_HOME
if [ "x$SOPCAST_HOME" = "x" ]; then
    # get the full path (without any relative bits)
    SOPCAST_HOME=`cd $DIRNAME/..; pwd`
fi
export SOPCAST_HOME

# Increase the maximum file descriptors if we can
if [ "$cygwin" = "false" ]; then
    MAX_FD_LIMIT=`ulimit -H -n`
    if [ $? -eq 0 ]; then
	if [ "$MAX_FD" = "maximum" -o "$MAX_FD" = "max" ]; then
	    # use the system max
	    MAX_FD="$MAX_FD_LIMIT"
	fi

	ulimit -n $MAX_FD
	if [ $? -ne 0 ]; then
	    warn "Could not set maximum file descriptor limit: $MAX_FD"
	fi
    else
	warn "Could not query system maximum file descriptor limit: $MAX_FD_LIMIT"
    fi
fi

# Setup the JVM
if [ "x$JAVA" = "x" ]; then
    if [ "x$JAVA_HOME" != "x" ]; then
	JAVA="$JAVA_HOME/bin/java"
    else
	JAVA="java"
    fi
fi

# Setup the classpath

# Include the JDK javac compiler for JSP pages. The default is for a Sun JDK
# compatible distribution which JAVA_HOME points to
if [ "x$JAVAC_JAR" = "x" ]; then
    JAVAC_JAR="$JAVA_HOME/lib/tools.jar"
fi
if [ ! -f "$JAVAC_JAR" ]; then
   # MacOSX does not have a seperate tools.jar
   if [ "$darwin" != "true" ]; then
      warn "Missing file: $JAVAC_JAR"
      warn "Unexpected results may occur.  Make sure JAVA_HOME points to a JDK and not a JRE."
   fi
fi



if [ -z "$SOPCAST_CLASSPATH" ]; then
	SOPCAST_CLASSPATH=".:$SOPCAST_HOME/build/classes:$SOPCAST_HOME/etc"
fi

DIRLIBS=`ls $SOPCAST_HOME/lib/*`
for i in ${DIRLIBS}; do
   if [ "$i" != "${DIRLIBS}" ] ; then
	if [ -z "$SOPCAST_CLASSPATH" ] ; then
		SOPCAST_CLASSPATH=$i
	else
		SOPCAST_CLASSPATH="$i":$SOPCAST_CLASSPATH
	fi
   fi
done

JAVA_OPTS="$JAVA_OPTS -Dprogram.name=$PROGNAME -Djava.library.path=$SOPCAST_HOME/lib"


# Display our environment
echo "========================================================================="
echo ""
echo ""
echo "  SOPCAST_HOME: $SOPCAST_HOME"
echo ""
echo "  JAVA: $JAVA"
echo ""
echo "  JAVA_OPTS: $JAVA_OPTS"
echo ""
echo "  CLASSPATH: $SOPCAST_CLASSPATH"
echo ""
echo "========================================================================="
echo ""

MAIN=MainWindow
STATUS=10
while [ $STATUS -eq 10 ]
do
# Execute the JVM
   "$JAVA" $JAVA_OPTS \
      -classpath "$SOPCAST_CLASSPATH" \
      $MAIN "$@"
   STATUS=$?
done

